@@ -17,7 +17,6 @@ package net.morilib.awk.expr;
 
 import net.morilib.awk.io.AwkFiles;
 import net.morilib.awk.namespace.AwkNamespace;
-import net.morilib.awk.value.AwkString;
 import net.morilib.awk.value.AwkValue;
 
 public class AwkConcatenator extends AwkExpression {
@@ -30,9 +29,9 @@ public class AwkConcatenator extends AwkExpression {
 	}
 
 	public AwkValue eval(AwkNamespace ns, AwkFiles o) {
-		return AwkString.valueOf(
-				e1.eval(ns, o).toString(ns) +
-				e2.eval(ns, o).toString(ns));
+		AwkValue r1 = e1.eval(ns, o), r2 = e2.eval(ns, o);
+
+		return AwkValue.concat(r1, r2, ns);
 	}
 
 }
